@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* this file is part of criawips, a gnome presentation application
  *
  * AUTHORS
@@ -29,6 +28,7 @@
 
 G_BEGIN_DECLS
 
+#ifndef G_DISABLE_ASSERT
 #ifdef G_HAVE_ISO_VARARGS
 #define	g_debug(...)	g_log  (G_LOG_DOMAIN,		\
 					G_LOG_LEVEL_DEBUG,	\
@@ -41,6 +41,9 @@ G_BEGIN_DECLS
 #else
 #error "We don't know cria_debug now..."
 #endif /* G_HAVE_ISO_VARGS */
+#else /* !G_DISABLE_ASSERT */
+#define g_debug(...)		G_STMT_START{ (void)0; }G_STMT_END
+#endif /* !G_DISABLE_ASSERT */
 
 G_END_DECLS
 
