@@ -2,34 +2,20 @@
 /* Generated data (by glib-mkenums) */
 
 #include <enumerations.h>
-#include <layout-block.h>
-
-/* enumerations from "layout-block.h" */
-GType
-cria_unit_get_type (void)
-{
-  static GType etype = 0;
-  if (etype == 0) {
-    static const GEnumValue values[] = {
-      { CRIA_UNIT_PIXEL, "CRIA_UNIT_PIXEL", "pixel" },
-      { CRIA_UNIT_PERCENT, "CRIA_UNIT_PERCENT", "percent" },
-      { 0, NULL, NULL }
-    };
-    etype = g_enum_register_static ("CriaUnit", values);
-  }
-  return etype;
-}
+#include "block.h"
 
+/* enumerations from "alignment.h" */
 GType
 cria_alignment_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
+      { CRIA_ALIGNMENT_UNSET, "CRIA_ALIGNMENT_UNSET", "unset" },
       { CRIA_ALIGNMENT_LEFT, "CRIA_ALIGNMENT_LEFT", "left" },
       { CRIA_ALIGNMENT_CENTER, "CRIA_ALIGNMENT_CENTER", "center" },
       { CRIA_ALIGNMENT_RIGHT, "CRIA_ALIGNMENT_RIGHT", "right" },
-      { CRIA_ALIGNMENT_JUSTIFTY, "CRIA_ALIGNMENT_JUSTIFTY", "justifty" },
+      { CRIA_ALIGNMENT_JUSTIFY, "CRIA_ALIGNMENT_JUSTIFY", "justify" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("CriaAlignment", values);
@@ -43,9 +29,10 @@ cria_valignment_get_type (void)
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { CRIA_ALIGNMENT_TOP, "CRIA_ALIGNMENT_TOP", "top" },
-      { CRIA_ALIGNMENT_MIDDLE, "CRIA_ALIGNMENT_MIDDLE", "middle" },
-      { CRIA_ALIGNMENT_BOTTOM, "CRIA_ALIGNMENT_BOTTOM", "bottom" },
+      { CRIA_VALIGNMENT_UNSET, "CRIA_VALIGNMENT_UNSET", "valignment-unset" },
+      { CRIA_ALIGNMENT_TOP, "CRIA_ALIGNMENT_TOP", "alignment-top" },
+      { CRIA_ALIGNMENT_MIDDLE, "CRIA_ALIGNMENT_MIDDLE", "alignment-middle" },
+      { CRIA_ALIGNMENT_BOTTOM, "CRIA_ALIGNMENT_BOTTOM", "alignment-bottom" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("CriaVAlignment", values);
