@@ -6,13 +6,11 @@
 
 #include <glib-object.h>
 
-#include <layout-block.h>
+#include "block.h"
 
 G_BEGIN_DECLS
-/* enumerations from "layout-block.h" */
+/* enumerations from "alignment.h" */
 
-GType cria_unit_get_type (void);
-#define CRIA_TYPE_UNIT (cria_unit_get_type())
 GType cria_alignment_get_type (void);
 #define CRIA_TYPE_ALIGNMENT (cria_alignment_get_type())
 GType cria_valignment_get_type (void);
