@@ -1,5 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* This file is part of criawips, a GNOME presentation application
+/* This file is part of criawips, a gnome presentation application
  *
  * AUTHORS
  *       Sven Herzberg        <herzi@gnome-de.org>
@@ -22,24 +21,16 @@
  * USA
  */
 
+#include "libglade-support.h"
+
 #include <string.h>
 
-#include "libglade-support.h"
+#include "slide-editor.h"
 #include "slide-list.h"
-#include "slide-view.h"
 
 GtkWidget*
 criawips_libglade_custom_handler (GladeXML* xml, gchar* func_name, gchar* widget_name, gchar* string1, gchar* string2, gint int1, gint int2, gpointer data) {
-	GtkWidget	* return_widget;
-
-	if (strcmp(widget_name, "main_slide_list") == 0) {
-		return_widget = cria_slide_list_new();
-	} else if(strcmp(widget_name, "main_slide_view") == 0) {
-		return_widget = cria_slide_view_new();
-	} else {
-		g_assert_not_reached();
-		return NULL;
-	}
+	GtkWidget	* return_widget = NULL;
 
 	gtk_widget_show(return_widget);
 
