@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* this file is part of criawips, a gnome presentation application
  *
  * AUTHORS
@@ -36,7 +35,7 @@ typedef struct _CriaMainWindow CriaMainWindow;
 typedef struct _CriaMainWindowClass CriaMainWindowClass;
 typedef struct _CriaMainWindowPriv CriaMainWindowPriv;
 
-CriaMainWindow*		  cria_main_window_new		       (const gchar	* text_uri);
+GtkWidget*		  cria_main_window_new		       (const gchar	* filename);
 GType			  cria_main_window_get_type	       (void);
 CriaPresentation*	  cria_main_window_get_presentation    (CriaMainWindow	* self);
 void			  cria_main_window_set_presentation    (CriaMainWindow	* self,
@@ -50,19 +49,13 @@ void			  cria_main_window_show_about	       (CriaMainWindow	* self);
 #define CRIA_IS_MAIN_WINDOW_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), CRIA_TYPE_MAIN_WINDOW))
 #define CRIA_MAIN_WINDOW_GET_CLASS(object)	(G_TYPE_INSTANCE_GET_CLASS((object), CRIA_TYPE_MAIN_WINDOW, CriaMainWindowClass))
 
-struct _CriaMainWindow
-{
-	GObject			  base_instance;
+struct _CriaMainWindow {
+	GtkWindow		  base_instance;
 	CriaMainWindowPriv	* priv;
 };
 
-struct _CriaMainWindowClass
-{
-	GObjectClass		  base_class;
-
-	/* signals */
-	void (*signal)	       (CriaMainWindow	* template,
-				const	gchar	* string);
+struct _CriaMainWindowClass {
+	GtkWindowClass		  base_class;
 };
 
 G_END_DECLS
