@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* this file is part of criawips, a gnome presentation application
  *
  * AUTHORS
@@ -39,5 +38,6 @@ main (
 	gtk_main ();
 
 	g_debug("main(): quitting");
+	go_font_shutdown();
 	return 0;
 }
