@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* this file is part of criawips, a gnome presentation application
  *
  * AUTHORS
@@ -31,8 +30,9 @@
 
 G_BEGIN_DECLS
 
-CriaPresentation* cria_presentation_parse_input_xml    (GsfInput        * input,
-							GError		**error);
+void cria_presentation_populate_from_xml_input (CriaPresentation* self,
+						GsfInput        * input,
+						GError		**error);
 
 G_END_DECLS
 
