@@ -21,44 +21,54 @@
  * USA
  */
 
+#include <glib-object.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
+
+#include <goffice/utils/go-units.h>
+
+#include "theme.h"
+
 #ifndef PRESENTATION_H
 #define PRESENTATION_H
 
-#include <glib-object.h>
-
-#include "slide.h"
-#include "theme.h"
-
 G_BEGIN_DECLS
 
 typedef struct _CriaPresentation	CriaPresentation;
 typedef struct _CriaPresentationClass	CriaPresentationClass;
 typedef struct _CriaPresentationPrivate	CriaPresentationPrivate;
 
+#include "slide.h"
+
 void		  cria_presentation_add_theme	       (CriaPresentation* self,
 							CriaTheme	* theme);
 void		  cria_presentation_append_slide       (CriaPresentation* self,
 							CriaSlide	* slide);
+const gchar	* cria_presentation_get_filename       (CriaPresentation* self);
 GType		  cria_presentation_get_type	       (void);
+const GnomeVFSURI* cria_presentation_get_uri	       (CriaPresentation* self);
 CriaSlide	* cria_presentation_get_slide	       (CriaPresentation* self,
 							guint		  index);
 gint		  cria_presentation_get_slide_index    (CriaPresentation* self,
 							CriaSlide const	* slide);
+const GoPoint	* cria_presentation_get_slide_size     (CriaPresentation* self);
 CriaTheme	* cria_presentation_get_theme	       (CriaPresentation* self,
 							const char	* theme);
 const gchar	* cria_presentation_get_title	       (CriaPresentation* self);
+void		  cria_presentation_insert_slide       (CriaPresentation* self,
+							CriaSlide       * slide,
+							gint		  position);
 guint		  cria_presentation_n_slides	       (CriaPresentation*self);
-CriaPresentation* cria_presentation_new		       (void);
+CriaPresentation* cria_presentation_new_default	       (void);
 CriaPresentation* cria_presentation_new_from_file      (const	gchar	* filename,
 							GError		**error);
-CriaPresentation* cria_presentation_new_from_uri       (const gchar	* text_uri,
+CriaPresentation* cria_presentation_new_from_text_uri  (const gchar	* text_uri,
 							GError		**error);
 void		  cria_presentation_set_title	       (CriaPresentation* self,
-							const char	* attribute);
-void		  cria_presentation_add_master_slide   (CriaPresentation* self,
-							CriaSlide	* master_slide);
+							const char	* title);
+void		  cria_presentation_set_uri	       (CriaPresentation* self,
+							GnomeVFSURI	* uri);
 
-#define CRIA_TYPE_PRESENTATION			(cria_presentation_get_type ())
+#define CRIA_TYPE_PRESENTATION			(cria_presentation_get_type())
 #define CRIA_PRESENTATION(object)		(G_TYPE_CHECK_INSTANCE_CAST((object), CRIA_TYPE_PRESENTATION, CriaPresentation))
 #define CRIA_PRESENTATION_CLASS(klass)		(G_TYPE_CHACK_CLASS_CAST((klass), CRIA_TYPE_PRESENTATION, CriaPresentationClass))
 #define CRIA_IS_PRESENTATION(object)		(G_TYPE_CHECK_INSTANCE_TYPE((object), CRIA_TYPE_PRESENTATION))
@@ -67,6 +77,8 @@ void		  cria_presentation_add_master_slide   (CriaPresentation* self,
 
 struct _CriaPresentation {
 	GObject			  base_instance;
+	/* GoPoint		* size = 5760x4320; */
+	/* gboolean		  saved; */
 	gchar			* title;
 	CriaPresentationPrivate	* priv;
 };
@@ -75,8 +87,9 @@ struct _CriaPresentationClass {
 	GObjectClass	  base_class;
 
 	/* signals */
-	void (*signal)	       (CriaPresentation	* template,
-				const	gchar	* string);
+	void (*inserted_slide)	       (CriaPresentation* self,
+					gint		  new_position,
+					CriaSlide	* new_slide);
 };
 
 G_END_DECLS
