@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* this file is part of criawips, a gnome presentation application
  *
  * AUTHORS
@@ -60,7 +59,8 @@ struct _CriaSlideShow {
 };
 
 struct _CriaSlideShowClass {
-	GtkWindowClass	  base_class;
+	GtkWindowClass		  base_class;
+	CriaSlide		* after_show;
 
 	/* signals */
 	void (*signal)	       (CriaSlideShow	* template,
