@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* this file is part of criawips a gnome presentation application
  *
  * AUTHORS
@@ -27,6 +26,7 @@
 #endif
 
 #include <stdint.h>
+#include <string.h>
 
 #include <glib-object.h>
 #include <glib.h>
@@ -35,19 +35,16 @@
 #include "debug.h"
 #include "theme.h"
 
-struct _CriaThemePrivate
-{
-	GHashTable	* layouts;
+struct _CriaThemePrivate {
+	GHashTable	* master_slides;
 };
 
-enum
-{
+enum {
 	PROP_0,
 	PROP_NAME
 };
 
-enum
-{
+enum {
 	SIGNAL,
 	N_SIGNALS
 };
@@ -68,32 +65,14 @@ static	void	cria_theme_signal	       (CriaTheme	* template,
 						const	gchar	* string);
 #endif
 void
-cria_theme_add_layout (
-		CriaTheme	* self,
-		CriaLayout	* layout)
-{
-	g_return_if_fail (CRIA_IS_THEME (self));
-	g_return_if_fail (CRIA_IS_LAYOUT (layout));
-	g_return_if_fail (g_hash_table_lookup (self->priv->layouts, cria_layout_get_name (layout)) == NULL);
+cria_theme_add_master_slide(CriaTheme* self, CriaSlide* master_slide) {
+	g_assert(CRIA_IS_THEME(self));
+	g_assert(CRIA_IS_SLIDE(master_slide));
+	g_assert(cria_theme_get_master_slide(self, cria_slide_get_title(master_slide)) == NULL);
 
-	g_debug ("cria_theme_add_layout(0x%x): adding 0x%x as \"%s\"", (uintptr_t)self, (uintptr_t)layout, cria_layout_get_name (layout));
-
-	g_hash_table_insert (
-			self->priv->layouts,
-			g_strdup (cria_layout_get_name (layout)),
-			layout);
-}
-
-CriaLayout*
-cria_theme_get_layout (
-		CriaTheme	* self,
-		const char	* layout)
-{
-	g_return_val_if_fail (CRIA_IS_THEME (self), NULL);
-
-	g_debug ("cria_theme_get_layout(0x%x): looking for \"%s\"", (uintptr_t)self, layout);
-
-	return CRIA_LAYOUT (g_hash_table_lookup (self->priv->layouts, layout));
+	g_hash_table_insert(self->priv->master_slides,
+			    g_strdup(cria_slide_get_title(master_slide)),
+			    master_slide);
 }
 
 static void
@@ -135,11 +114,18 @@ cria_theme_class_init (CriaThemeClass	* cria_theme_class)
 			);
 }
 
-const char*
-cria_theme_get_name (
-		CriaTheme	* self)
-{
-	g_return_val_if_fail (CRIA_IS_THEME(self), NULL);
+CriaSlide*
+cria_theme_get_master_slide(CriaTheme* self, const gchar* name) {
+	g_assert(self != NULL && CRIA_IS_THEME(self));
+
+	g_debug ("Theme::getMasterSlide(0x%x): looking for \"%s\"", (uintptr_t)self, name);
+
+	return CRIA_SLIDE(g_hash_table_lookup(self->priv->master_slides, name));
+}
+
+const gchar*
+cria_theme_get_name(CriaTheme* self) {
+	g_assert(CRIA_IS_THEME(self));
 	
 	return self->name;
 }
@@ -202,19 +188,25 @@ cria_theme_get_type (void)
 }
 
 static void
-cria_theme_init (CriaTheme *self)
-{
-	self->priv = g_new0 (CriaThemePrivate, 1);
+cria_theme_init(CriaTheme *self) {
+	self->priv = g_new0(CriaThemePrivate, 1);
 
-	self->priv->layouts = g_hash_table_new_full (
-			g_str_hash,
-			g_str_equal,
-			g_free,
-			g_object_unref);
+	self->priv->master_slides = g_hash_table_new_full(g_str_hash,
+							  g_str_equal,
+							  g_free,
+							  g_object_unref);
+}
+
+CriaTheme*
+cria_theme_new(const gchar* name) {
+	g_return_val_if_fail(name != NULL && strlen(name), NULL);
+	
+	CriaTheme* self = g_object_new(CRIA_TYPE_THEME, "name", name, NULL);
+	return self;
 }
 
 void
-cria_theme_set_name (
+cria_theme_set_name(
 		CriaTheme	* self,
 		const gchar	* name)
 {
